# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`tajine`](#tajine): Deploy and configure Tajine, a registration authority pluged to CFSSL PKI.

### Data types

* [`Tajine::Config::Webapp`](#Tajine--Config--Webapp): Describes configuration parameters

## Classes

### <a name="tajine"></a>`tajine`

Deploy and configure Tajine, a registration authority pluged to CFSSL PKI.

#### Examples

##### 

```puppet
class { 'tajine':
  sys_rootpath      => '/var/www/tajine.example.org',
  sys_rootpath_mode => '0700',
  sys_user          => 'www-data',
  sys_group         => 'www-data',
  webapp            => {
    trusted_hosts => '^example\.org$|^tajine\.example\.org$',
  },
}
```

#### Parameters

The following parameters are available in the `tajine` class:

* [`download_url`](#-tajine--download_url)
* [`download_checksum`](#-tajine--download_checksum)
* [`checksum_type`](#-tajine--checksum_type)
* [`app_secret`](#-tajine--app_secret)
* [`config_path`](#-tajine--config_path)
* [`var_path`](#-tajine--var_path)
* [`sys_usermanage`](#-tajine--sys_usermanage)
* [`sys_user`](#-tajine--sys_user)
* [`sys_group`](#-tajine--sys_group)
* [`sys_rootpath`](#-tajine--sys_rootpath)
* [`sys_rootpath_mode`](#-tajine--sys_rootpath_mode)
* [`cfssl_host`](#-tajine--cfssl_host)
* [`cfssl_port`](#-tajine--cfssl_port)
* [`db_manage`](#-tajine--db_manage)
* [`db_host`](#-tajine--db_host)
* [`db_version`](#-tajine--db_version)
* [`db_user`](#-tajine--db_user)
* [`db_password`](#-tajine--db_password)
* [`db_name`](#-tajine--db_name)
* [`smtp_host`](#-tajine--smtp_host)
* [`smtp_port`](#-tajine--smtp_port)
* [`smtp_user`](#-tajine--smtp_user)
* [`smtp_password`](#-tajine--smtp_password)
* [`enforce_https`](#-tajine--enforce_https)
* [`webapp`](#-tajine--webapp)

##### <a name="-tajine--download_url"></a>`download_url`

Data type: `Stdlib::HTTPSUrl`

URL where Tajine archive is stored.

Default value: `'https://gitlab.adullact.net/adullact/pki/tajine/-/package_files/868/download'`

##### <a name="-tajine--download_checksum"></a>`download_checksum`

Data type: `String[1]`

Archive file checksum (match checksum_type) used to verify of archive file.

Default value: `'6a2229eb0b9bd5090578989b433597295d9de6e33f150674f26c87115caed7bc'`

##### <a name="-tajine--checksum_type"></a>`checksum_type`

Data type: `Enum['md5', 'sha1', 'sha2', 'sha256', 'sha384', 'sha512']`

Checksum type given with download_checksum.

Default value: `'sha256'`

##### <a name="-tajine--app_secret"></a>`app_secret`

Data type: `String[1]`

Application secret is required to generate CSRF tokens

Default value: `'ThisTokenIsNotSoSecretChangeIt'`

##### <a name="-tajine--config_path"></a>`config_path`

Data type: `Stdlib::Absolutepath`

Directory where Tajine configuration file is stored.

Default value: `'/etc/tajine'`

##### <a name="-tajine--var_path"></a>`var_path`

Data type: `Stdlib::Absolutepath`

Directory where Tajine stores var files.

Default value: `'/var/tajine'`

##### <a name="-tajine--sys_usermanage"></a>`sys_usermanage`

Data type: `Boolean`

To enable/disable the creation of system user and group. To permit manage then by external process.

Default value: `true`

##### <a name="-tajine--sys_user"></a>`sys_user`

Data type: `String[1]`

Operating system user account owner of Tajine files

Default value: `'tajine'`

##### <a name="-tajine--sys_group"></a>`sys_group`

Data type: `String[1]`

Operating system group owner of Tajine files

Default value: `'tajine'`

##### <a name="-tajine--sys_rootpath"></a>`sys_rootpath`

Data type: `Stdlib::Absolutepath`

Path where Tajine is installed

Default value: `'/opt/tajine'`

##### <a name="-tajine--sys_rootpath_mode"></a>`sys_rootpath_mode`

Data type: `String`

Unix mode set to path defined by $sys_rootpath

Default value: `'0750'`

##### <a name="-tajine--cfssl_host"></a>`cfssl_host`

Data type: `Stdlib::HTTPUrl`

CFSSL host to use

Default value: `'http://127.0.0.1'`

##### <a name="-tajine--cfssl_port"></a>`cfssl_port`

Data type: `Stdlib::Port`

CFSSL port to use

Default value: `8080`

##### <a name="-tajine--db_manage"></a>`db_manage`

Data type: `Boolean`

To enable/disable installation of local PostgreSQl server, creation of role and database. To permit manage then by external process.

Default value: `true`

##### <a name="-tajine--db_host"></a>`db_host`

Data type: `Stdlib::Host`

PostgreSQL server to use

Default value: `'127.0.0.1'`

##### <a name="-tajine--db_version"></a>`db_version`

Data type: `String[1]`

Version of PostgreSQL server

Default value: `'14'`

##### <a name="-tajine--db_user"></a>`db_user`

Data type: `String[1]`

Database user used to connect PostgreSQL server

Default value: `'dbtajine'`

##### <a name="-tajine--db_password"></a>`db_password`

Data type: `Variant[String[1], Sensitive[String]]`

Database password used to connect PostgreSQL server

Default value: `Sensitive.new('changeit')`

##### <a name="-tajine--db_name"></a>`db_name`

Data type: `String[1]`

Database name used by Tajine

Default value: `'tajine'`

##### <a name="-tajine--smtp_host"></a>`smtp_host`

Data type: `Stdlib::Host`

SMTP host to use

Default value: `'127.0.0.1'`

##### <a name="-tajine--smtp_port"></a>`smtp_port`

Data type: `Stdlib::Port`

SMTP port to use

Default value: `25`

##### <a name="-tajine--smtp_user"></a>`smtp_user`

Data type: `Optional[String[1]]`

SMTP user used with SMTP auth. If user is email, use username%40example.org instead of username@example.org.

Default value: `undef`

##### <a name="-tajine--smtp_password"></a>`smtp_password`

Data type: `Optional[Variant[String[1], Sensitive[String]]]`

SMTP password used with SMTP auth

Default value: `undef`

##### <a name="-tajine--enforce_https"></a>`enforce_https`

Data type: `Boolean`

To enable/disable enforced https.

Default value: `true`

##### <a name="-tajine--webapp"></a>`webapp`

Data type: `Tajine::Config::Webapp`

Tajine configuration parameters starting with WEBAPP_ , for all possible parameters, see:
https://gitlab.adullact.net/adullact/pki/tajine/-/blob/main/documentation/sysadmin/91_common_configuration.md

Default value: `{}`

## Data types

### <a name="Tajine--Config--Webapp"></a>`Tajine::Config::Webapp`

Describes configuration parameters

Alias of `Hash[String[1], String[1]]`

